@@ -1,6 +1,6 @@
 package Statocles::Page;
 # ABSTRACT: Base class for rendering objects
-$Statocles::Page::VERSION = '0.059';
+$Statocles::Page::VERSION = '0.060';
 use Statocles::Base 'Role';
 use Statocles::Template;
 
@@ -124,6 +124,16 @@ has search_priority => (
     default => sub { 0.5 },
 );
 
+# _rendered_html
+#
+# The HTML rendered from the page. Cached.
+
+has _rendered_html => (
+    is => 'rw',
+    isa => Str,
+    predicate => '_has_rendered_html',
+);
+
 
 sub vars {
     my ( $self ) = @_;
@@ -137,6 +147,9 @@ sub vars {
 
 sub render {
     my ( $self, %args ) = @_;
+
+    return $self->_rendered_html if $self->_has_rendered_html;
+
     my %vars = (
         %{ $self->data },
         %args,
@@ -149,10 +162,13 @@ sub render {
         %vars,
     );
 
-    return $self->layout->render(
+    my $html = $self->layout->render(
         content => $content,
         %vars,
     );
+
+    $self->_rendered_html( $html );
+    return $html;
 }
 
 
@@ -186,7 +202,7 @@ Statocles::Page - Base class for rendering objects
 
 =head1 VERSION
 
-version 0.059
+version 0.060
 
 =head1 DESCRIPTION
 
@@ -306,6 +322,8 @@ Render the page, using the L<template|Statocles::Page/template> and wrapping
 with the L<layout|Statocles::Page/layout>. Give any extra C<%vars> to the
 template, layout, and page C<content> method (if applicable).
 
+The result of this method is cached.
+
 =head2 links
 
     my @links = $page->links( $key );
