@@ -1,6 +1,6 @@
 package Statocles::Page::Document;
 # ABSTRACT: Render document objects into HTML
-$Statocles::Page::Document::VERSION = '0.059';
+$Statocles::Page::Document::VERSION = '0.060';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 use Statocles::Template;
@@ -73,13 +73,27 @@ around vars => sub {
 };
 
 
+has _rendered_sections => (
+    is => 'rw',
+    isa => ArrayRef,
+    predicate => '_has_rendered_sections',
+);
+
 sub sections {
     my ( $self ) = @_;
-    my @sections = split /\n---\n/, $self->document->content;
-    return
+
+    if ( $self->_has_rendered_sections ) {
+        return @{ $self->_rendered_sections };
+    }
+
+    my @sections =
         map { $self->markdown->markdown( $_ ) }
         map { $self->_render_content_template( $_, {} ) }
-        @sections;
+        split /\n---\n/,
+        $self->document->content;
+
+    $self->_rendered_sections( \@sections );
+    return @sections;
 }
 
 
@@ -121,7 +135,7 @@ Statocles::Page::Document - Render document objects into HTML
 
 =head1 VERSION
 
-version 0.059
+version 0.060
 
 =head1 DESCRIPTION
 
