@@ -1,6 +1,6 @@
 package Statocles::Page::File;
 # ABSTRACT: A page wrapping a file (handle)
-$Statocles::Page::File::VERSION = '0.059';
+$Statocles::Page::File::VERSION = '0.060';
 use Statocles::Base 'Class';
 with 'Statocles::Page';
 
@@ -25,7 +25,7 @@ sub vars { die "Unimplemented" }
 
 sub render {
     my ( $self ) = @_;
-    return $self->file_path ? $self->file_path->openr_raw : $self->fh;
+    return $self->file_path ? $self->file_path : $self->fh;
 }
 
 1;
@@ -40,7 +40,7 @@ Statocles::Page::File - A page wrapping a file (handle)
 
 =head1 VERSION
 
-version 0.059
+version 0.060
 
 =head1 SYNOPSIS
 
