@@ -1,6 +1,6 @@
 package Statocles::Store;
 # ABSTRACT: The source for data documents and files
-$Statocles::Store::VERSION = '0.059';
+$Statocles::Store::VERSION = '0.060';
 use Statocles::Base 'Class';
 use Scalar::Util qw( weaken blessed );
 use Statocles::Document;
@@ -267,6 +267,9 @@ sub write_file {
             $fh->print( $line );
         }
     }
+    elsif ( blessed $content && $content->isa( 'Path::Tiny' ) ) {
+        $content->copy( $full_path->touchpath );
+    }
     else {
         $full_path->touchpath->spew_utf8( $content );
     }
@@ -293,7 +296,7 @@ Statocles::Store - The source for data documents and files
 
 =head1 VERSION
 
-version 0.059
+version 0.060
 
 =head1 DESCRIPTION
 
