@@ -1,6 +1,6 @@
 package Statocles::Template;
 # ABSTRACT: A template object to pass around
-$Statocles::Template::VERSION = '0.059';
+$Statocles::Template::VERSION = '0.060';
 use Statocles::Base 'Class';
 use Mojo::Template;
 use Scalar::Util qw( blessed );
@@ -32,6 +32,20 @@ has theme => (
     coerce => Theme->coercion,
 );
 
+has _template => (
+    is => 'ro',
+    isa => InstanceOf['Mojo::Template'],
+    lazy => 1,
+    default => sub {
+        my ( $self ) = @_;
+        my $t = Mojo::Template->new(
+            name => $self->path,
+        );
+        $t->parse( $self->content )->build;
+        return $t;
+    },
+);
+
 
 around BUILDARGS => sub {
     my ( $orig, $self, @args ) = @_;
@@ -55,9 +69,7 @@ around BUILDARGS => sub {
 
 sub render {
     my ( $self, %args ) = @_;
-    my $t = Mojo::Template->new(
-        name => $self->path,
-    );
+    my $t = $self->_template;
     $t->prepend( $self->_prelude( '_tmpl', keys %args ) );
 
     my $content;
@@ -78,7 +90,11 @@ sub render {
             return $args{site}->markdown->markdown( $text );
         };
 
-        $content = $t->render( $self->content, \%args );
+        my $err = $t->compile;
+        if ( $err ) {
+            die "Error in template: " . $err;
+        }
+        $content = $t->interpret( \%args );
     }
 
     if ( blessed $content && $content->isa( 'Mojo::Exception' ) ) {
@@ -123,7 +139,7 @@ Statocles::Template - A template object to pass around
 
 =head1 VERSION
 
-version 0.059
+version 0.060
 
 =head1 DESCRIPTION
 
