@@ -1,6 +1,6 @@
 package Statocles::Test;
 # ABSTRACT: Common test routines for Statocles
-$Statocles::Test::VERSION = '0.059';
+$Statocles::Test::VERSION = '0.060';
 use Statocles::Base;
 use Test::More;
 use Test::Exception;
@@ -154,10 +154,15 @@ sub test_pages {
         }
 
         my $output = $page->render( site => $site );
+
         # Handle filehandles from render
         if ( ref $output eq 'GLOB' ) {
             $output = do { local $/; <$output> };
         }
+        # Handle Path::Tiny from render
+        elsif ( Scalar::Util::blessed( $output ) && $output->isa( 'Path::Tiny' ) ) {
+            $output = $output->slurp_raw;
+        }
 
         if ( $page->path =~ /[.](?:html|rss|atom)$/ ) {
             my $dom = Mojo::DOM->new( $output );
@@ -298,7 +303,7 @@ Statocles::Test - Common test routines for Statocles
 
 =head1 VERSION
 
-version 0.059
+version 0.060
 
 =head1 DESCRIPTION
 
